Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(4707)

Unified Diff: chrome/test/chromedriver/test/run_py_tests.py

Issue 189133005: Rename chromium_testshell target to chrome_shell_apk. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Rebase Created 6 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/test/chromedriver/chrome/device_manager.cc ('k') | chrome/test/chromedriver/test/test_expectations » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/test/chromedriver/test/run_py_tests.py
diff --git a/chrome/test/chromedriver/test/run_py_tests.py b/chrome/test/chromedriver/test/run_py_tests.py
index 111fea6e22e8a69422bcdd1f15e99de3b018291f..48083b2be96f9fdab7d45ca20e4c5cf84dfd0629 100755
--- a/chrome/test/chromedriver/test/run_py_tests.py
+++ b/chrome/test/chromedriver/test/run_py_tests.py
@@ -121,16 +121,16 @@ _ANDROID_NEGATIVE_FILTER['chrome_stable'] = (
_ANDROID_NEGATIVE_FILTER['chrome'])
_ANDROID_NEGATIVE_FILTER['chrome_beta'] = (
_ANDROID_NEGATIVE_FILTER['chrome'])
-_ANDROID_NEGATIVE_FILTER['chromium_test_shell'] = (
+_ANDROID_NEGATIVE_FILTER['chrome_shell'] = (
_ANDROID_NEGATIVE_FILTER['chrome'] + [
# ChromiumTestShell doesn't support multiple tabs.
'ChromeDriverTest.testGetWindowHandles',
'ChromeDriverTest.testSwitchToWindow',
'ChromeDriverTest.testShouldHandleNewWindowLoadingProperly',
]
)
_ANDROID_NEGATIVE_FILTER['chromedriver_webview_shell'] = (
- _ANDROID_NEGATIVE_FILTER['chromium_test_shell'])
+ _ANDROID_NEGATIVE_FILTER['chrome_shell'])
class ChromeDriverBaseTest(unittest.TestCase):
« no previous file with comments | « chrome/test/chromedriver/chrome/device_manager.cc ('k') | chrome/test/chromedriver/test/test_expectations » ('j') | no next file with comments »
@@ -121,16 +121,16 @@ _ANDROID_NEGATIVE_FILTER['chrome_stable'] = (
_ANDROID_NEGATIVE_FILTER['chrome'] + [
- # ChromiumTestShell doesn't support multiple tabs.
+ # ChromeShell doesn't support multiple tabs.
'ChromeDriverTest.testGetWindowHandles',
'ChromeDriverTest.testSwitchToWindow',

Powered by Google App Engine
This is Rietveld 408576698